@@ -6,7 +6,9 @@ from .kafka_client import KafkaClient
 from .order_client import OrderClient
 from .vpn_client import VpnGatewayClient
 from proxy_tools import proxy
-
+from .ess_client import EssClient
+from .vpc_client import VpcClient
+from .cs_client import CsClient
 
 prod_mapper = {
     'cdn': CdnClient,
@@ -14,7 +16,10 @@ prod_mapper = {
     'dds': DdsClient,
     'kafka': KafkaClient,
     'order': OrderClient,
-    'vpn': VpnGatewayClient
+    'vpn': VpnGatewayClient,
+    'ess': EssClient,
+    'vpc': VpcClient,
+    'cs': CsClient
 }
 
 
@@ -52,4 +57,19 @@ def order_client():
 
 @proxy
 def vpn_client():
-    return get_current_client('vpn')
\ No newline at end of file
+    return get_current_client('vpn')
+
+
+@proxy
+def ess_client():
+    return get_current_client('ess')
+
+
+@proxy
+def vpc_client():
+    return get_current_client('vpc')
+
+
+@proxy
+def cs_client():
+    return get_current_client('cs')
\ No newline at end of file
