@@ -227,29 +227,3 @@ class AliIPsec:
     @property
     def vpn_bgp_config(self):
         return self.object.get('VpnBgpConfig')
-
-
-class AliRouteEntry():
-    def __init__(self, object):
-        self.object = object
-
-    @classmethod
-    def get(cls, vpn_id):
-        result = vpn_client.describe_route({'VpnGatewayId': vpn_id})
-        if result:
-            return cls(result)
-        return None
-
-    @classmethod
-    def list(cls, vpn_id):
-        result = vpn_client.describe_route({'VpnGatewayId': vpn_id})
-        vpn_routes = result.get('VpnRouteEntries', {}).get('VpnRouteEntry', []) or []
-        return [cls.get(ipsec['VpnConnectionId']) for vpn_route in vpn_routes]
-
-    @classmethod
-    def create(cls, params):
-        result = vpn_client.create_ipsec_gateway(params)
-        return result.get('VpnConnectionId')
-
-    def delete(self):
-        return vpn_client.delete_ipsec_gateway({'VpnConnectionId': self.external_id})
\ No newline at end of file
