@@ -44,6 +44,13 @@ class HuaweiEip:
             return
         return cls(public_ip)
 
+    @classmethod
+    def list(cls):
+        public_ips = hw_eip_client.list_eip()
+        if not public_ips:
+            return
+        return [cls(public_ip) for public_ip in public_ips]
+
     @classmethod
     def create(cls, params=None):
         create_response = hw_eip_client.create_eip(body_params=params)
